@@ -18,7 +18,7 @@ public:
 	~DirBrowserFormAction() override;
 	void prepare() override;
 	void init() override;
-	KeyMapHintEntry* get_keymap_hint() override;
+	const std::vector<KeyMapHintEntry>& get_keymap_hint() const override;
 
 	std::string id() const override
 	{
