@@ -16,10 +16,12 @@
 #include "configcontainer.h"
 #include "logger.h"
 
-#include "utils.rs.h"
+#include "libnewsboat-ffi/src/utils.rs.h"
 
 namespace newsboat {
 
+class CurlHandle;
+
 // Forward declaration for a type from htmlrenderer.h
 enum class LinkType;
 
@@ -58,12 +60,18 @@ std::string locale_to_utf8(const std::string& text);
 
 std::string get_command_output(const std::string& cmd);
 std::string http_method_str(const HTTPMethod method);
+
 std::string retrieve_url(const std::string& url,
 	ConfigContainer* cfgcont = nullptr,
 	const std::string& authinfo = "",
 	const std::string* body = nullptr,
-	const HTTPMethod method = HTTPMethod::GET,
-	CURL* easyhandle = nullptr);
+	const HTTPMethod method = HTTPMethod::GET);
+std::string retrieve_url(const std::string& url,
+	CurlHandle& easyhandle,
+	ConfigContainer* cfgcont = nullptr,
+	const std::string& authinfo = "",
+	const std::string* body = nullptr,
+	const HTTPMethod method = HTTPMethod::GET);
 std::string run_program(const char* argv[], const std::string& input);
 
 std::string resolve_tilde(const std::string&);
@@ -113,7 +121,7 @@ std::string quote(const std::string& str);
 
 std::string quote_if_necessary(const std::string& str);
 
-void set_common_curl_options(CURL* handle, ConfigContainer* cfg);
+void set_common_curl_options(CurlHandle& handle, ConfigContainer* cfg);
 
 curl_proxytype get_proxy_type(const std::string& type);
 
@@ -156,6 +164,8 @@ nonstd::optional<LinkType> podcast_mime_to_link_type(const std::string&
 
 std::string get_default_browser();
 
+std::string md5hash(const std::string& input);
+
 /// The tag and Git commit ID the program was built from, or a pre-defined
 /// value from config.h if there is no Git directory.
 std::string program_version();
