@@ -71,10 +71,7 @@ impl FsLock {
                 new_lock_path.display()
             );
             let pid = process::id().to_string();
-            if let Err(reason) = file
-                .set_len(0)
-                .and_then(|_| file.write_all(&pid.as_bytes()))
-            {
+            if let Err(reason) = file.set_len(0).and_then(|_| file.write_all(pid.as_bytes())) {
                 log!(Level::Debug, "FsLock: Failed to write PID");
                 return Err(fmt!(
                     &gettext("Failed to write PID to lock file '%s': %s"),
@@ -109,12 +106,11 @@ impl FsLock {
                 pid
             );
             Err(fmt!(
-                &gettext("Failed to lock '%s', already locked by process with PID %{}"),
+                &gettext("Failed to lock '%s', already locked by process with PID %s"),
                 new_lock_path
                     .to_str()
                     .unwrap_or(&gettext("<filename containing invalid UTF-8 codepoint>")),
-                PRIi64,
-                *pid as i64
+                &(*pid).to_string()
             ))
         }
     }
