@@ -38,7 +38,6 @@
 #include "freshrssapi.h"
 #include "freshrssurlreader.h"
 #include "fileurlreader.h"
-#include "globals.h"
 #include "inoreaderapi.h"
 #include "inoreaderurlreader.h"
 #include "itemrenderer.h"
@@ -138,8 +137,7 @@ int Controller::run(const CliArgsParser& args)
 
 	if (args.do_import()) {
 		LOG(Level::INFO, "Importing OPML file from %s", args.importfile());
-		import_opml(args.importfile(), configpaths.url_file());
-		return EXIT_SUCCESS;
+		return import_opml(args.importfile(), configpaths.url_file());
 	}
 
 	LOG(Level::INFO, "nl_langinfo(CODESET): %s", nl_langinfo(CODESET));
@@ -361,8 +359,7 @@ int Controller::run(const CliArgsParser& args)
 	}
 	const auto error_message = urlcfg->reload();
 	if (error_message.has_value()) {
-		std::cout << error_message.value() << std::endl << std::endl;
-		return EXIT_FAILURE;
+		std::cout << error_message.value().message << std::endl << std::endl;
 	} else if (!args.do_export() && !args.silent()) {
 		std::cout << _("done.") << std::endl;
 	}
@@ -724,7 +721,10 @@ int Controller::import_opml(const std::string& opmlFile,
 	auto urlReader = FileUrlReader(urlFile);
 	const auto error_message = urlReader.reload(); // Load existing URLs
 	if (error_message.has_value()) {
-		std::cout << error_message.value() << std::endl;
+		std::cout << strprintf::fmt(
+				_("Error importing OPML to urls file %s: %s"),
+				urlFile, error_message.value().message)
+			<< std::endl;
 		return EXIT_FAILURE;
 	}
 
@@ -794,7 +794,7 @@ void Controller::reload_urls_file()
 {
 	const auto error_message = urlcfg->reload();
 	if (error_message.has_value()) {
-		v->get_statusline().show_message(error_message.value());
+		v->get_statusline().show_message(error_message.value().message);
 		return;
 	}
 
