@@ -31,9 +31,11 @@ FileBrowserFormAction::FileBrowserFormAction(View* vv,
 	, quit(false)
 	, files_list("files", FormAction::f, cfg->get_configvalue_as_int("scrolloff"))
 {
-	// In filebrowser, keyboard focus is at the input field, so user can't
-	// possibly use 'q' key to exit the dialog
+	// In filebrowser, keyboard focus is at the input field, so user will be
+	// unable to use alphanumeric keys to confirm or quit the dialog (e.g. they
+	// can't quit with the default `q` bind).
 	KeyMap* keys = vv->get_keymap();
+	keys->set_key(OP_OPEN, "ENTER", id());
 	keys->set_key(OP_QUIT, "ESC", id());
 	vv->set_keymap(keys);
 }
