@@ -91,7 +91,7 @@ void ItemViewFormAction::prepare()
 	 */
 	if (do_redraw) {
 		{
-			ScopeMeasure("itemview::prepare: rendering");
+			ScopeMeasure sm("itemview::prepare: rendering");
 			// XXX HACK: render once so that we get a proper widget width
 			recalculate_widget_dimensions();
 		}
@@ -203,8 +203,14 @@ bool ItemViewFormAction::process_operation(Operation op,
 		do_redraw = true;
 		break;
 	case OP_ENQUEUE: {
-		if (item->enclosure_url().length() > 0 &&
-			utils::is_http_url(item->enclosure_url())) {
+		if (item->enclosure_url().empty()) {
+			v->get_statusline().show_error(_("Item has no enclosures."));
+			return false;
+		} else if (!utils::is_http_url(item->enclosure_url())) {
+			v->get_statusline().show_error(strprintf::fmt(
+					_("Item's enclosure has non-http link: '%s'"), item->enclosure_url()));
+			return false;
+		} else {
 			const EnqueueResult result = v->get_ctrl()->enqueue_url(item, feed);
 			rsscache->update_rssitem_unread_and_enqueued(item, feed->rssurl());
 			switch (result.status) {
@@ -228,10 +234,6 @@ bool ItemViewFormAction::process_operation(Operation op,
 					strprintf::fmt(_("Failed to open queue file: %s."), result.extra_info));
 				return false;
 			}
-		} else {
-			v->get_statusline().show_error(strprintf::fmt(
-					_("Invalid URL: '%s'"), item->enclosure_url()));
-			return false;
 		}
 	}
 	break;
@@ -284,7 +286,9 @@ bool ItemViewFormAction::process_operation(Operation op,
 				args->size() > 0 ? (*args)[0] : "");
 			qna_responses.push_back(feed->title());
 		} else {
-			this->start_bookmark_qna(utils::utf8_to_locale(item->title()), item->link(), "",
+			this->start_bookmark_qna(
+				utils::utf8_to_locale(item->title()),
+				item->link(),
 				feed->title());
 		}
 		break;
@@ -559,30 +563,35 @@ void ItemViewFormAction::set_head(const std::string& s,
 
 void ItemViewFormAction::handle_cmdline(const std::string& cmd)
 {
-	std::vector<std::string> tokens = utils::tokenize_quoted(cmd);
-	if (!tokens.empty()) {
-		if (tokens[0] == "save" && tokens.size() >= 2) {
-			std::string filename = utils::resolve_tilde(tokens[1]);
+	const auto command = FormAction::parse_command(cmd);
+	switch (command.type) {
+	case CommandType::SAVE:
+		if (!command.args.empty()) {
+			handle_save(command.args.front());
+		}
+		break;
+	default:
+		FormAction::handle_parsed_command(command);
+	}
+}
 
-			if (filename == "") {
-				v->get_statusline().show_error(_("Aborted saving."));
-			} else {
-				try {
-					v->get_ctrl()->write_item(
-						item, filename);
-					v->get_statusline().show_message(strprintf::fmt(
-							_("Saved article to %s"),
-							filename));
-				} catch (...) {
-					v->get_statusline().show_error(strprintf::fmt(
-							_("Error: couldn't save "
-								"article to %s"),
-							filename));
-				}
-			}
-
-		} else {
-			FormAction::handle_cmdline(cmd);
+void ItemViewFormAction::handle_save(const std::string& filename_param)
+{
+	std::string filename = utils::resolve_tilde(filename_param);
+	if (filename == "") {
+		v->get_statusline().show_error(_("Aborted saving."));
+	} else {
+		try {
+			v->get_ctrl()->write_item(
+				item, filename);
+			v->get_statusline().show_message(strprintf::fmt(
+					_("Saved article to %s"),
+					filename));
+		} catch (...) {
+			v->get_statusline().show_error(strprintf::fmt(
+					_("Error: couldn't save "
+						"article to %s"),
+					filename));
 		}
 	}
 }
